import Foundation

struct Complex {
    var real: Double
    var imaginary: Double
}

let a = Complex(real: 1.0, imaginary: 2.0)

extension Complex: FloatLiteralConvertible {
    init(floatLiteral value: FloatLiteralType) {
        self.real = value
        self.imaginary = 0.0
    }
}

let b: Complex = 2.0

extension Complex: IntegerLiteralConvertible {
    init(integerLiteral value: IntegerLiteralType) {
        self.real = Double(value)
        self.imaginary = 0.0
    }
}

let c: Complex = 2

extension Complex: StringLiteralConvertible {
    typealias UnicodeScalarLiteralType = StringLiteralType
    init(unicodeScalarLiteral value: UnicodeScalarLiteralType) {
        self.init(stringLiteral: value)
    }
    
    typealias ExtendedGraphemeClusterLiteralType = StringLiteralType
    init(extendedGraphemeClusterLiteral value: ExtendedGraphemeClusterLiteralType) {
        self.init(stringLiteral: value)
    }
    
    init(stringLiteral value: StringLiteralType) {
        let scanner: NSScanner = NSScanner(string: String(value))
        self.real = 0.0
        self.imaginary = 0.0
        
        if scanner.scanDouble(&self.real) == false {
            return
        }
        
        if scanner.scanString("+", intoString: nil) == false {
            return
        }
        
        if scanner.scanDouble(&self.imaginary) == false {
            return
        }
        
        if scanner.scanString("i", intoString: nil) == false {
            return
        }
    }
}

let d: Complex = "1+2i"
let e: Complex = "2.0+1.0i"
let f: Complex = "3+-4i"
let g: Complex = "1 + 2 i"
let h: Complex = "3-4i"
let i: Complex = "foo"
let j: Complex = "4ty-two"

let s: Selector = "hashValue"
